/*
 * Cantata
 *
 * Copyright (c) 2011-2013 Craig Drummond <craig.p.drummond@gmail.com>
 *
 * ----
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef MOUNTPOINTS_H
#define MOUNTPOINTS_H

#include <QObject>
#include <QSet>
#include <QString>

class QFile;

class MountPoints : public QObject
{
    Q_OBJECT

public:
    static MountPoints * self();

    MountPoints();
    int currentToken() const { return token; }
    bool isMounted(const QString &mp) const;

Q_SIGNALS:
    void updated();

private Q_SLOTS:
    void updateMountPoints();

private:
    int token;
    QSet<QString> current;
    QFile *mounts;
};

#endif // MOUNTPOINTS_H
